<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * Register the scripts that Bizznis will use.
 *
 * @since 1.2.0
 *
 * @uses BIZZNIS_ASSETS_JS_URL
 * @uses PARENT_THEME_VERSION
 */
add_action( 'wp_enqueue_scripts', 'bizznis_register_scripts' );
function bizznis_register_scripts() {
	$suffix = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	wp_register_script( 'skip-links',  BIZZNIS_ASSETS_JS_URL . "/skip-links.js", array(), PARENT_THEME_VERSION, true );
	wp_register_script( 'drop-down-menu',  BIZZNIS_ASSETS_JS_URL . "/drop-down-menu.js", array( 'jquery' ), PARENT_THEME_VERSION, true );
	wp_register_script( 'responsive-menu',  BIZZNIS_ASSETS_JS_URL . "/responsive-menu.js", array( 'jquery' ), PARENT_THEME_VERSION, true );
	wp_register_script( 'html5shiv', BIZZNIS_ASSETS_JS_URL . "/html5shiv.js", array(), '3.7.3', true );
}

/**
 * Enqueue the scripts used on the front-end of the site.
 *
 * @since 1.0.0
 */
add_action( 'wp_enqueue_scripts', 'bizznis_load_scripts' );
function bizznis_load_scripts() {
	global $wp_scripts;
	
	// If a single post or page, threaded comments are enabled, and comments are open.
	if ( is_singular() && get_option( 'thread_comments' ) && comments_open() ) {
		wp_enqueue_script( 'comment-reply' );		
	}
	
	// If accessibility support for 'skip-links' is enabled.
	if ( bizznis_a11y( 'skip-links' ) ) {
		wp_enqueue_script( 'skip-links' );
	}
	
	// If accessibility support for 'skip-links' is enabled.
	if ( bizznis_a11y( 'drop-down-menu' ) ) {
		wp_enqueue_script( 'drop-down-menu' );
	}
	
	// If responsive menu support is enabled.
	$responsive_menu = bizznis_get_option( 'nav_extras_responsive' );
	if ( current_theme_supports( 'bizznis-responsive-menu' ) && ! empty( $responsive_menu ) ) {		
		wp_enqueue_script( 'responsive-menu' );
		wp_localize_script( 'responsive-menu', 'bizzmenuL10n', array(
			'selector' => $responsive_menu,
		) );
	}
	
	//* HTML5 shiv.
	wp_enqueue_script( 'html5shiv' );
	$wp_scripts->add_data( 'html5shiv', 'conditional', 'lt IE 9' );
}

/**
 * Conditionally enqueues the scripts used in the admin.
 *
 * @since 1.0.0
 */
add_action( 'admin_enqueue_scripts', 'bizznis_load_admin_scripts' );
function bizznis_load_admin_scripts( $hook_suffix ) {
	// If we're on a Bizznis admin screen.
	if ( bizznis_is_menu_page( 'bizznis' ) ) {
		bizznis_load_admin_js();
	}
}

/**
 * Enqueues the custom script used in the admin, and localizes several strings or values used in the scripts.
 *
 * @since 1.0.0
 */
function bizznis_load_admin_js() {
	wp_enqueue_script( 'bizznis_admin_js', BIZZNIS_ASSETS_JS_URL . '/admin.js', array( 'jquery' ), PARENT_THEME_VERSION, true );
	
	// Strings.
	$strings = array(
		'categoryChecklistToggle' => __( 'Select / Deselect All', 'bizznis' ),
		'saveAlert'               => __( 'The changes you made will be lost if you navigate away from this page.', 'bizznis' ),
		'confirmUpgrade'          => __( 'Updating Bizznis will overwrite the current installed version of Bizznis. Are you sure you want to update?. "Cancel" to stop, "OK" to update.', 'bizznis' ),
		'confirmReset'            => __( 'Are you sure you want to reset?', 'bizznis' ),
	);
	wp_localize_script( 'bizznis_admin_js', 'bizznisL10n', $strings );
}